@@ -168,7 +168,7 @@ def rms(
     arr: _Union[_pd.DataFrame, _pd.Series], axis: _Union[None, int] = 0, level: _Union[None, int] = None
 ) -> _Union[_pd.Series, _pd.DataFrame]:
     """Trivial function to compute root mean square"""
-    return (arr ** 2).mean(axis=axis, level=level) ** 0.5
+    return (arr**2).mean(axis=axis, level=level) ** 0.5
 
 
 def get_std_bounds(a: _np.ndarray, axis: _Union[None, int, _Tuple[int, ...]] = None, sigma_coeff: int = 3):
@@ -227,12 +227,21 @@ def degminsec2decdeg(series):
     return _deg + sign * _min / 60 + sign * _sec / 3600
 
 
-def decdeg2degminsec(arr:_np.ndarray):
-    """Expects input array of decimal degrees. Could be used with 2D arrays: decdeg2degminsec(arr[:,:2])"""
-    sign = _np.sign(arr)
-    arr_u = _np.abs(arr)
-    d = arr_u.astype(int)
-    arr_u_remainder = arr_u - d
+def decdeg2degminsec(a: _np.ndarray):
+    """Converts decimal degrees to string representation in the form of degrees minutes seconds as in the sinex SITE/ID block. Could be used with multiple columns at once (2D ndarray)"""
+    arr = a.reshape((-1))
+    d = arr.astype(int)
+    arr_u_remainder = _np.abs(arr - d)
     m = (arr_u_remainder * 60).astype(int)
-    s = (arr_u_remainder - m/60)*3600
-    return sign*d,m,s.round(1)
\ No newline at end of file
+    s = (arr_u_remainder - m / 60) * 3600
+    degminsec_series = (
+        _pd.Series(d.astype(str)).str.rjust(3)
+        + _pd.Series(m.astype(str)).str.rjust(3)
+        + _pd.Series(s.round(1).astype(str)).str.rjust(5)
+    )
+    return degminsec_series.values.reshape(a.shape)
+
+
+def throw_if_index_duplicates(df):
+    if df.index.has_duplicates:
+        raise ValueError(f"Duplicated index entries present, see below:\n {df[df.index.duplicated()].to_string()}")
