@@ -1,6 +1,7 @@
 """Base time conversion functions"""
 from datetime import datetime as _datetime
 from io import StringIO as _StringIO
+from typing import Union as _Union
 
 import numpy as _np
 import pandas as _pd
@@ -128,7 +129,7 @@ def gpswkD2dt(gpswkD):
 
 
 def yydoysec2datetime(
-    arr: _np.ndarray or _pd.Series, recenter: bool = True, as_j2000: bool = True, delimiter: str = ":"
+    arr: _Union[_np.ndarray, _pd.Series, list], recenter: bool = False, as_j2000: bool = True, delimiter: str = ":"
 ) -> _np.ndarray:
     """Converts snx YY:DOY:SSSSS [snx] or YYYY:DOY:SSSSS [bsx/bia] object Series/ndarray to datetime64.
     recenter overrides day seconds value to midday
@@ -147,27 +148,25 @@ def yydoysec2datetime(
     return datetime2j2000(datetime64) if as_j2000 else datetime64
 
 
-def datetime2yydoysec(datetime):
+def datetime2yydoysec(datetime: _Union[_np.ndarray, _pd.Series]) -> _np.ndarray:
     """datetime64[s] -> yydoysecond
-    NaNs become ""
-    year 2100 become 00:000:00000"""
-    nan_mask = _np.isnan(datetime)
-    datetime_no_nans = datetime[~nan_mask]
-    date_years = datetime_no_nans.astype("datetime64[Y]")
-    date_days = datetime_no_nans.astype("datetime64[D]")
-    doy = _pd.Series((date_days - date_years + 1).astype(int).astype(str))
-    seconds = _pd.Series((datetime_no_nans - date_days).astype("timedelta64[s]").astype(int).astype(str))
-    yydoysec_no_nans = (
-        _pd.Series(date_years.astype(str)).str.slice(2).values  # need U4+1 for [Y] so str
+    The '2000-01-01T00:00:00' (-43200 J2000 for 00:000:00000) datetime becomes 00:000:00000 as it should,
+    No masking and overriding with year 2100 is needed"""
+    if isinstance(datetime, _pd.Series):
+        datetime = (
+            datetime.values
+        )  # .astype("datetime64[Y]") called on ndarray will return 4-digit year, not YYYY-MM-DD as in case of Series
+    datetime_Y = datetime.astype("datetime64[Y]")
+    datetime_D = datetime.astype("datetime64[D]")
+    doy = _pd.Series((datetime_D - datetime_Y).astype(int).astype(str))
+    seconds = _pd.Series((datetime - datetime_D).astype("timedelta64[s]").astype(int).astype(str))
+    yydoysec = (
+        _pd.Series(datetime_Y.astype(str)).str.slice(2).values
         + ":"
         + doy.str.zfill(3).values
         + ":"
         + seconds.str.zfill(5).values
     )
-    yydoysec_no_nans[date_years == _np.datetime64("2100")] = "00:000:00000"
-
-    yydoysec = _np.empty_like(datetime, dtype=object)
-    yydoysec[~nan_mask] = yydoysec_no_nans
     return yydoysec
 
 
@@ -178,7 +177,7 @@ def gpsweeksec2datetime(gps_week: _np.ndarray, tow: _np.ndarray, as_j2000: bool
     return datetime
 
 
-def datetime2gpsweeksec(array: _np.ndarray, as_decimal=False) -> tuple or _np.ndarray:
+def datetime2gpsweeksec(array: _np.ndarray, as_decimal=False) -> _Union[tuple, _np.ndarray]:
     if array.dtype == int:
         ORIGIN = _gn_const.J2000_ORIGIN.astype(int) - _gn_const.GPS_ORIGIN.astype(int)
         gps_time = array + ORIGIN  # need int conversion for the case of datetime64
@@ -211,6 +210,10 @@ def j20002datetime(j2000secs: _np.ndarray, as_datetime: bool = False) -> _np.nda
     return datetime64
 
 
+def j20002yydoysec(j2000secs: _np.ndarray) -> _np.ndarray:
+    return datetime2yydoysec(j20002datetime(j2000secs))
+
+
 def datetime2mjd(array: _np.ndarray) -> tuple:
     mjd_seconds = (array - _gn_const.MJD_ORIGIN).astype(int)  # seconds
     return mjd_seconds // _gn_const.SEC_IN_DAY, (mjd_seconds % _gn_const.SEC_IN_DAY) / _gn_const.SEC_IN_DAY
@@ -264,11 +267,13 @@ def j20002rnxdt(j2000secs: _np.ndarray) -> _np.ndarray:
 
 
 def strdatetime2datetime(dt_arr, as_j2000=True):
-    """ conversion of IONEX map headers ndarray Y M D h m s to datetime64"""
+    """conversion of IONEX map headers ndarray Y M D h m s to datetime64"""
     datetime = (
-        dt_arr[:, 0].astype("datetime64[Y]") # no 1970 origin issue when from str
-        + (dt_arr[:, 1].astype("timedelta64[M]") - 1) # datetime year starts with 01 months (e.g. 2019-01) hence 1 must be subtracted from months
-        + (dt_arr[:, 2].astype("timedelta64[D]") - 1) # same with days - starts with 01, e.g., 2019-01-01
+        dt_arr[:, 0].astype("datetime64[Y]")  # no 1970 origin issue when from str
+        + (
+            dt_arr[:, 1].astype("timedelta64[M]") - 1
+        )  # datetime year starts with 01 months (e.g. 2019-01) hence 1 must be subtracted from months
+        + (dt_arr[:, 2].astype("timedelta64[D]") - 1)  # same with days - starts with 01, e.g., 2019-01-01
         + (dt_arr[:, 3].astype("timedelta64[h]"))
         + (dt_arr[:, 4].astype("timedelta64[m]"))
         + (dt_arr[:, 5].astype("timedelta64[s]"))
