@@ -225,12 +225,15 @@ def difftrace(trace1_path, trace2_path, tol, std_coeff, log_lvl, plot):
     _logging.info(msg=f":diffutil -----testing trace states-----")
     states1 = _gn_io.trace._read_trace_states(trace1)
     states2 = _gn_io.trace._read_trace_states(trace2)
+
     status = 0
     if (states1 is None) and (states2 is None):
         _logging.log(msg=f":diffutil both compared files are missing states data -> OK", level=log_lvl)
     elif (states1 is None) or (states2 is None):
         status += -1  # don't wait, throw error right away as smth bad happened, errors have been logged
     else:
+        _gn_aux.throw_if_index_duplicates(states1)
+        _gn_aux.throw_if_index_duplicates(states2)
         diffstd_states = _valvar2diffstd(states1.iloc[:, :2], states2.iloc[:, :2], std_coeff=std_coeff, trace=True)
         if diffstd_states.attrs["EXTRA_SATS"] != []:
             _logging.warning(msg=f':diffutil found no counterpart for: {sorted(diffstd_states.attrs["EXTRA_SATS"])}')
@@ -240,11 +243,14 @@ def difftrace(trace1_path, trace2_path, tol, std_coeff, log_lvl, plot):
     _logging.info(msg=f":diffutil -----testing trace residuals-----")
     resids1 = _gn_io.trace._read_trace_residuals(trace1)
     resids2 = _gn_io.trace._read_trace_residuals(trace2)
+
     if (resids1 is None) and (resids2 is None):
         _logging.log(msg=f":diffutil both compared files are missing residuals data -> OK", level=log_lvl)
     elif (resids1 is None) or (resids2 is None):
         status += -1  # don't wait, throw error right away as smth bad happened, errors have been logged
     else:
+        _gn_aux.throw_if_index_duplicates(resids1)
+        _gn_aux.throw_if_index_duplicates(resids2)
         diffstd_residuals = _valvar2diffstd(resids1.iloc[:, 2:], resids2.iloc[:, 2:], std_coeff=std_coeff, trace=True)
         status += _compare_sat_postfit_residuals(diffstd_residuals, tol=tol, log_lvl=log_lvl)
         status += _compare_nonsat_postfit_residuals(diffstd_residuals, tol=tol, log_lvl=log_lvl)
@@ -254,8 +260,8 @@ def difftrace(trace1_path, trace2_path, tol, std_coeff, log_lvl, plot):
 
 def diffsnx(snx1_path, snx2_path, tol, std_coeff, log_lvl):
     """Compares two sinex files"""
-    snx1_df = _gn_io.sinex._get_snx_vector(path_or_bytes=snx1_path, stypes=("EST",), snx_format=True, verbose=True)
-    snx2_df = _gn_io.sinex._get_snx_vector(path_or_bytes=snx2_path, stypes=("EST",), snx_format=True, verbose=True)
+    snx1_df = _gn_io.sinex._get_snx_vector(path_or_bytes=snx1_path, stypes=("EST",), format='long', verbose=True)
+    snx2_df = _gn_io.sinex._get_snx_vector(path_or_bytes=snx2_path, stypes=("EST",), format='long', verbose=True)
 
     if (snx1_df is None) or (snx2_df is None):
         return -1  # don't wait, throw error right away as smth bad happened, errors have been logged
