@@ -12,9 +12,9 @@ def read_stec(path_or_bytes):
         _BytesIO(_gn_io.common.path2bytes(path_or_bytes)),
         comment="#",
         header=None,
-        usecols=[1, 2, 3, 4, 5, 6, 7],
+        usecols=[1, 2, 3, 4, 5, 6, 8],
         names=["WEEK", "TOW", "SITE", "SAT", "VAL", "VAR", "LAYER"],  # type:ignore
-        dtype={1: int, 2: int, 3: object, 4: _gn_const.PRN_CATEGORY, 5: float, 6: float, 7: int},
+        dtype={1: int, 2: int, 3: object, 4: object, 5: float, 6: float, 8: int},
     )  # type:ignore
     datetime = _gn_datetime.gpsweeksec2datetime(stec.WEEK.values, stec.TOW.values, as_j2000=True)
     return stec.drop(columns=["WEEK", "TOW"]).set_index([datetime, "SITE", "SAT", "LAYER"])
